"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Utils_1 = require("../Utils/Utils");
class Component extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Component);
        const componentName = args.componentName[0].toUpperCase() + args.componentName.substr(1);
        const componentType = flags.type;
        const fileToCompile = [
            {
                sourceFile: '__test__/component_name.test.tsx.hbs',
                compiledFile: `__test__/${componentName}.test.tsx`,
                filePath: componentName,
                compilerData: { 'componentName': componentName }
            },
            {
                sourceFile: 'component_name.tsx.hbs',
                compiledFile: `${componentName}.tsx`,
                filePath: componentName,
                compilerData: { 'componentName': componentName }
            },
            {
                sourceFile: 'index.ts.hbs',
                compiledFile: 'index.ts',
                filePath: componentName,
                compilerData: { 'componentName': componentName }
            }
        ];
        if (componentName) {
            // move to switch case
            if (componentType === 'class' || componentType === 'c') {
                // create folder
                Utils_1.Utils.CreateFolder(componentName);
                // copy template file
                Utils_1.Utils.CopyTemplate(componentName, '/component/simple_class');
                // move css file
                Utils_1.Utils.MoveFile(componentName, 'component_name.css', `${componentName}.css`);
                // compile template
                Utils_1.Utils.CompileTemplate(fileToCompile);
            }
            else if (componentType === 'function' || componentType === 'f') {
                console.log('Function coming soon!');
            }
        }
        else {
            await Component.run(['--help']);
        }
    }
}
exports.default = Component;
Component.description = 'create an empty component';
Component.examples = [
    `$ reactscript-cli component testComponent`,
];
Component.flags = {
    help: command_1.flags.help({ char: 'h' }),
    type: command_1.flags.string({
        char: 't',
        options: [
            'class',
            'c',
            'function',
            'f'
        ],
        required: true
    })
};
Component.args = [
    {
        name: 'componentName'
    }
];
